/*============================= MiscUTMCoord.m ==============================*/
/* MiscUTMCoord class contains and supports values representing locations
   in a Universal Transverse Mercator coordinate system.

   DMA Release 0.8, Copyright @1993 by Genesis Project, Ltd. All Rights
   Reserved. For further information on terms and conditions see:
		Documentation/GISKit/Agreements-Legal-README

HISTORY
25-Feb-93  Dale Amon at GPL
	   Created.
*/

#import <misckit/miscgiskit.h>

@implementation MiscUTMCoord

/*===========================================================================*/
/* Initialization methods */
/*===========================================================================*/
/* DESIGNATED INITIALIZER */

-initDescription: (char *) txt constants: anObject
 {return 
	[super initDescription: txt
		     converter: [MiscPlanetCoordConverter new]
		     constants: anObject];
 }

/*---------------------------------------------------------------------------*/
/* Block the designated initializer of our parent class */

-initDescription: (char *) txt
       converter: (id <MiscCoordConverterServer>) aConverter
       constants: anObject
 {	[self error:"  %s class should not be sent '%s' messages\n",
            [[self class] name], sel_getName(_cmd)];
	return self;
 }


/*===========================================================================*/
/* Coordinate handling methods */
/*===========================================================================*/
/* set UTM grid coord value */

-setCoordEastingMeters: (double) east
        northingMeters: (double) north
       elevationMeters: (double) alt
 {	[self setCoord: east : north : alt];
	return self;
 }


/*---------------------------------------------------------------------------*/
/* Get UTM grid coord value */

-coordEastingMeters: (double *) east
     northingMeters: (double *) north
    elevationMeters: (double *) alt
 {	[self coord: east : north : alt];
	return self;
 }


/*---------------------------------------------------------------------------*/
/* UTM coordinates are easting, northing and elevation above the local
   mean radius.
*/

-(double) easting   {return [self coord1];}
-(double) northing  {return [self coord2];}
-(double) elevation {return [self coord3];}

@end
